@@ -34,3 +34,20 @@ expect_identical(ncol(r3), 4L)
 expect_identical(r3[.N, v2], "e")
 expect_identical(r3[.N, levs_v1], 2L)
 expect_identical(r3[.N, levs_v2], 2L)
+
+# check default codes
+r4 <- hier_grid(h1, h2, add_dups = FALSE, add_levs = TRUE, add_default_codes = TRUE)
+expect_identical(nrow(r4), 24L)
+expect_identical(ncol(r4), 6L)
+expect_identical(r4[1, v1], "Total")
+expect_identical(r4[1, v2], "Total")
+expect_identical(r4[1, levs_v1], 1L)
+expect_identical(r4[1, levs_v2], 1L)
+expect_identical(r4[1, default_v1], "0000")
+expect_identical(r4[1, default_v2], "000")
+expect_identical(r4[.N, v1], "C")
+expect_identical(r4[.N, v2], "e")
+expect_identical(r4[.N, levs_v1], 2L)
+expect_identical(r4[.N, levs_v2], 2L)
+expect_identical(r4[.N, default_v1], "0300")
+expect_identical(r4[.N, default_v2], "050")
